%define       anolis_release 2
%global       dir_name     IPMITOOL
%global       dir_version  1_8_18

Name:         ipmitool
Summary:      Utility for IPMI control
Version:      1.8.18
Release:      %{anolis_release}%{?dist}
License:      BSD
URL:          https://github.com/ipmitool/ipmitool
Source0:      %{url}/archive/refs/tags//%{name}-%{version}.tar.gz
Source1:      openipmi-ipmievd.sysconf
Source2:      ipmievd.service
Source3:      exchange-bmc-os-info.service
Source4:      exchange-bmc-os-info.sysconf
Source5:      set-bmc-url.sh
Source6:      exchange-bmc-os-info

Patch1:       0001-CVE-2011-4339-OpenIPMI.patch
Patch2:       0002-openssl.patch
Patch3:       0003-ipmitool-1.8.11-set-kg-key.patch
Patch4:       0004-slowswid.patch
Patch5:       0005-sensor-id-length.patch
Patch6:       0006-enable-usb.patch
Patch7:       0007-check-input.patch
Patch8:       0008-add-extern.patch
Patch9:       0009-best-cipher.patch
Patch10:      0010-pef-missing-newline.patch
Patch11:      0011-expand-sensor-name-column.patch
Patch12:      0012-CVE-2020-5208.patch
Patch13:      0013-fru-Fix-crashes-on-6-bit-ASCII-strings.patch

BuildRequires: openssl-devel
BuildRequires: readline-devel
BuildRequires: ncurses-devel
%{?systemd_requires}
BuildRequires: systemd
# bootstrap
BuildRequires: automake
BuildRequires: autoconf
BuildRequires: libtool
Obsoletes: OpenIPMI-tools < 2.0.14-3
Provides: OpenIPMI-tools = 2.0.14-3


%description
This package contains a utility for interfacing with devices that support
the Intelligent Platform Management Interface specification.  IPMI is
an open standard for machine health, inventory, and remote power control.

This utility can communicate with IPMI-enabled devices through either a
kernel driver such as OpenIPMI or over the RMCP LAN protocol defined in
the IPMI specification.  IPMIv2 adds support for encrypted LAN
communications and remote Serial-over-LAN functionality.

It provides commands for reading the Sensor Data Repository (SDR) and
displaying sensor values, displaying the contents of the System Event
Log (SEL), printing Field Replaceable Unit (FRU) information, reading and
setting LAN configuration, and chassis power control.


%package -n ipmievd
Summary: IPMI event daemon for sending events to syslog
Requires: ipmitool
%{?systemd_requires}
BuildRequires: systemd

%description -n ipmievd
ipmievd is a daemon which will listen for events from the BMC that are
being  sent to the SEL and also log those messages to syslog.


%package -n bmc-snmp-proxy
Summary: Reconfigure SNMP to include host SNMP agent within BMC
Requires: net-snmp
Requires: exchange-bmc-os-info
BuildArch: noarch

%description -n bmc-snmp-proxy
Given a host with BMC, this package would extend system configuration
of net-snmp to include redirections to BMC based SNMP.


%package -n exchange-bmc-os-info
Summary: Let OS and BMC exchange info
Requires: hostname
Requires: ipmitool
%{?systemd_requires}
BuildRequires: systemd
BuildRequires: make
BuildArch: noarch

%description -n exchange-bmc-os-info
Given a host with BMC, this package would pass the hostname &
OS information to the BMC and also capture the BMC ip info
for the host OS to use.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -n %{name}-%{dir_name}_%{dir_version} -p1

for f in AUTHORS ChangeLog; do
    iconv -f iso-8859-1 -t utf8 < ${f} > ${f}.utf8
    mv ${f}.utf8 ${f}
done

%build
# --disable-dependency-tracking speeds up the build
# --enable-file-security adds some security checks
# --disable-intf-free disables FreeIPMI support - we don't want to depend on
#   FreeIPMI libraries, FreeIPMI has its own ipmitoool-like utility.

# begin: release auto-tools
# Used to be needed by aarch64 support, now only cxoem patch makefiles are left.
aclocal
libtoolize --automake --copy
autoheader
automake --foreign --add-missing --copy
aclocal
autoconf
automake --foreign
# end: release auto-tools

%configure --disable-dependency-tracking --enable-file-security --disable-intf-free
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

install -Dpm 644 %{SOURCE2} %{buildroot}%{_unitdir}/ipmievd.service
install -Dpm 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/ipmievd
install -Dm 644 %{SOURCE3} %{buildroot}%{_unitdir}/exchange-bmc-os-info.service
install -Dm 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/exchange-bmc-os-info
install -Dm 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/set-bmc-url.sh
install -Dm 755 %{SOURCE6} %{buildroot}%{_libexecdir}/exchange-bmc-os-info


install -Dm 644 contrib/bmc-snmp-proxy.sysconf %{buildroot}%{_sysconfdir}/sysconfig/bmc-snmp-proxy
install -Dm 644 contrib/bmc-snmp-proxy.service %{buildroot}%{_unitdir}/bmc-snmp-proxy.service
install -Dm 755 contrib/bmc-snmp-proxy         %{buildroot}%{_libexecdir}/bmc-snmp-proxy

rm -rf %{buildroot}/%{_datadir}/doc/ipmitool 

%generate_compatibility_deps

%post -n ipmievd
%systemd_post ipmievd.service

%preun -n ipmievd
%systemd_preun ipmievd.service

%postun -n ipmievd
%systemd_postun_with_restart ipmievd.service

%post -n exchange-bmc-os-info
%systemd_post exchange-bmc-os-info.service

%preun -n exchange-bmc-os-info
%systemd_preun exchange-bmc-os-info.service

%postun -n exchange-bmc-os-info
%systemd_postun_with_restart exchange-bmc-os-info.service


%triggerun -- ipmievd < 1.8.11-7
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply ipmievd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save ipmievd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del ipmievd >/dev/null 2>&1 || :
/bin/systemctl try-restart ipmievd.service >/dev/null 2>&1 || :

%files
%dir %{abidir}
%{_bindir}/ipmitool
%{abidir}/ipmitool-option.list
%{_mandir}/man1/ipmitool.1*
%{_datadir}/ipmitool
%license COPYING

%files -n ipmievd
%config(noreplace) %{_sysconfdir}/sysconfig/ipmievd
%{_unitdir}/ipmievd.service
%{_sbindir}/ipmievd
%{abidir}/ipmievd-option.list
%{_mandir}/man8/ipmievd.8*

%files -n exchange-bmc-os-info
%config(noreplace) %{_sysconfdir}/sysconfig/exchange-bmc-os-info
%{_sysconfdir}/profile.d/set-bmc-url.sh
%{_unitdir}/exchange-bmc-os-info.service
%{_libexecdir}/exchange-bmc-os-info

%files -n bmc-snmp-proxy
%config(noreplace) %{_sysconfdir}/sysconfig/bmc-snmp-proxy
%{_unitdir}/bmc-snmp-proxy.service
%{_libexecdir}/bmc-snmp-proxy

%files doc
%doc AUTHORS ChangeLog README

%changelog
* Fri Dec 02 2022 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.8.18-2
- Add a patch and doc package

* Fri Apr 15 2022 yuanhui <yuanhui@linux.alibaba.com> - 1.8.18-1
- Init ipmitool for anolis os 23
